summaryrefslogtreecommitdiffstats
path: root/plugin/smb4k_konqplugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'plugin/smb4k_konqplugin.h')
-rw-r--r--plugin/smb4k_konqplugin.h32
1 files changed, 17 insertions, 15 deletions
diff --git a/plugin/smb4k_konqplugin.h b/plugin/smb4k_konqplugin.h
index 7f57324..fbefb26 100644
--- a/plugin/smb4k_konqplugin.h
+++ b/plugin/smb4k_konqplugin.h
@@ -26,10 +26,10 @@
#endif
#include <konqsidebarplugin.h>
-#include <qstring.h>
-#include <qwidget.h>
-#include <qvbox.h>
-#include <qwidgetstack.h>
+#include <tqstring.h>
+#include <tqwidget.h>
+#include <tqvbox.h>
+#include <tqwidgetstack.h>
#include <kpopupmenu.h>
#include <ktoolbar.h>
#include <khtml_part.h>
@@ -40,11 +40,12 @@
#include <kparts/factory.h>
-class smb4kWidget : public QVBox
+class smb4kWidget : public TQVBox
{
Q_OBJECT
+ TQ_OBJECT
public:
- smb4kWidget( QWidget * parent = 0, const char * name = 0, WFlags f = 0 );
+ smb4kWidget( TQWidget * tqparent = 0, const char * name = 0, WFlags f = 0 );
private:
@@ -53,25 +54,26 @@ private:
class KonqSidebar_Smb4K : public KonqSidebarPlugin
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Construct a @ref KonqSidebarPlugin.
*
* @param inst The sidebar's kinstance class.
* @param parent The sidebar internal button info class responsible for this plugin.
* @param widgetParent The container which will contain the plugins widget.
* @param desktopName The filename of the configuration file.
- * @param name A Qt object name for your plugin.
+ * @param name A TQt object name for your plugin.
**/
- KonqSidebar_Smb4K(KInstance *inst,QObject *parent,QWidget *widgetParent, QString &desktopName, const char* name=0);
+ KonqSidebar_Smb4K(KInstance *inst,TQObject *tqparent,TQWidget *widgetParent, TQString &desktopName, const char* name=0);
/** destructor */
~KonqSidebar_Smb4K();
KHTMLPart* m_part;
- virtual QWidget *getWidget(){ return (QWidget*)widget;}
- virtual void *provides(const QString &) {return 0;}
- void emitStatusBarText (const QString &) {;}
+ virtual TQWidget *getWidget(){ return (TQWidget*)widget;}
+ virtual void *provides(const TQString &) {return 0;}
+ void emitStatusBarText (const TQString &) {;}
private:
/**
@@ -90,7 +92,7 @@ protected:
*/
smb4kWidget *widget;
- QString currentKonquerorURL;
+ TQString currentKonquerorURL;
virtual void handleURL(const KURL &url);
@@ -117,7 +119,7 @@ protected slots:
/**
* Called from mounter when a share is mounted
*/
- void slotMountedShare( const QString & );
+ void slotMountedShare( const TQString & );
/**
* Called from the mounter just before a share is unmounted. This slot
* changes the URL to the user's home so that we can unmount the share
@@ -126,7 +128,7 @@ protected slots:
* @param mountpoint The mount point of the share that's going to
* be unmounted.
*/
- void slotPrepareUnmount( const QString &mounpoint );
+ void slotPrepareUnmount( const TQString &mounpoint );
signals:
// see <konqsidebarplugin.h>
void openURLRequest(const KURL &url,
@@ -53,25 +54,26 @@ private:
*
* @param inst The sidebar's kinstance class.
- * @param parent The sidebar internal button info class responsible for this plugin.
+ * @param tqparent The sidebar internal button info class responsible for this plugin.
* @param widgetParent The container which will contain the plugins widget.
* @param desktopName The filename of the configuration file.